from pathlib import Path

from conf.testing import output_path
from model_server.util import autonumber_new_directory, get_matching_files, loop_workflow
from extensions.chaeo.models import PatchStackObjectClassifier
from extensions.chaeo.workflows import infer_object_map_from_zstack
from extensions.ilastik.models import IlastikPixelClassifierModel



if __name__ == '__main__':
    where_czi = 'c:/Users/rhodes/projects/proj0004-marine-photoactivation/data/exp0038/AutoMic/20230906-163415/Selection'
    where_output = autonumber_new_directory(
        output_path,
        'zmask_to_automic',
    )

    px_ilp = Path.home() / 'model_server' / 'testing' / 'zmask' / 'AF405-bodies_boundaries.ilp'
    ob_ilp = Path.home() / 'model_server' / 'testing' / 'zmask' / 'auto_obj_after.ilp'

    params = {
        'pxmap_threshold': 0.25,
        'pxmap_foreground_channel': 0,
        'segmentation_channel': 0,
        'patches_channel': 4,
        'zmask_filters': {'area': (1e3, 1e8)},
    }

    input_files = get_matching_files(where_czi, 'czi', coord_filter={'P': (0, 10)}, )

    models = [
        IlastikPixelClassifierModel(params={'project_file': Path(px_ilp)}),
        PatchStackObjectClassifier(params={'project_file': Path(ob_ilp)})
    ]

    loop_workflow(
        input_files,
        where_output,
        infer_object_map_from_zstack,
        models,
        params,
        catch_and_continue=False,
    )

    print('Finished')